# Useful deep learning functions

### Quickstart

Install with `pip install aladdin` and (for example) load check_accuracy:
```python
from aladdin import check_accuracy
accuracy = check_accuracy(loader, model)
```

Will develop and detail which are available later:)